#
# spec file for package python-impacket
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binaries impacket-GetADUsers impacket-GetADComputers impacket-Get-GPPPassword impacket-GetLAPSPassword impacket-GetNPUsers impacket-GetUserSPNs impacket-DumpNTLMInfo impacket-addcomputer impacket-atexec impacket-changepasswd impacket-dacledit impacket-dcomexec impacket-describeTicket impacket-dpapi impacket-esentutl impacket-exchanger impacket-findDelegation impacket-getArch impacket-getPac impacket-getST impacket-getTGT impacket-goldenPac impacket-karmaSMB impacket-keylistattack impacket-kintercept impacket-lookupsid impacket-machine_role impacket-mimikatz impacket-mqtt_check impacket-mssqlclient impacket-mssqlinstance impacket-net impacket-netview impacket-ntfs-read impacket-ntlmrelayx impacket-owneredit impacket-ping impacket-ping6 impacket-psexec impacket-raiseChild impacket-rbcd impacket-rdp_check impacket-reg impacket-registry-read impacket-rpcmap impacket-rpcdump impacket-sambaPipe impacket-samrdump impacket-secretsdump impacket-services impacket-smbclient impacket-smbexec impacket-smbserver impacket-sniff impacket-sniffer impacket-split impacket-ticketConverter impacket-ticketer impacket-tstool impacket-wmiexec impacket-wmipersist impacket-wmiquery

Name:           python-impacket
Version:        0.12.0
Release:        2.2
Summary:        Python3 module to easily build and dissect network protocols
# License: modified Apache-1.1 (see file LICENSE)
License:        Apache-1.1
Group:          Development/Languages/Python
URL:            https://www.secureauth.com/labs/open-source-tools/impacket
#Git-Clone:     https://github.com/fortra/impacket.git
Source:         https://files.pythonhosted.org/packages/source/i/impacket/impacket-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 1.0
Requires:       python-charset-normalizer
Requires:       python-ldap3 >= 2.5
Requires:       python-ldapdomaindump >= 0.9.0
Requires:       python-pyOpenSSL >= 0.13.1
Requires:       python-pyasn1 >= 0.2.3
Requires:       python-pycryptodomex
Requires:       python-setuptools
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Flask >= 1.0}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module ldap3 >= 2.5}
BuildRequires:  %{python_module ldapdomaindump >= 0.9.0}
BuildRequires:  %{python_module pyOpenSSL >= 0.13.1}
BuildRequires:  %{python_module pyasn1 >= 0.2.3}
BuildRequires:  %{python_module pycryptodomex}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
Impacket is a collection of Python classes for working with network
protocols. Impacket is focused on providing low-level
programmatic access to the packets and for some protocols (e.g.
SMB1-3 and MSRPC) the protocol implementation itself.
Packets can be constructed from scratch, as well as parsed from
raw data, and the object oriented API makes it simple to work with
deep hierarchies of protocols. The library provides a set of tools
as examples of what can be done within the context of this library.

%prep
%autosetup -p1 -n impacket-%{version}
sed -e '/^#!\//, 1d' -i \
  impacket/examples/ntlmrelayx/servers/socksserver.py \
  impacket/examples/mssqlshell.py \
  impacket/mqtt.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand cd %{buildroot}%{_bindir} && find . -name "*.py" -exec sh -c 'mv $0 impacket-`basename "$0" .py`' '{}' \;
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_bindir}/$b
done
#
%python_expand rm -f %{buildroot}%{_datadir}/doc/impacket/LICENSE
%python_expand rm -f %{buildroot}%{_datadir}/doc/impacket/README.md
%python_expand %fdupes %{buildroot}%{$python_sitelib}
#
%python_expand rm %{buildroot}%{_bindir}/_current_flavor

%post
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_install_alternative " .. b .. "\n"))
end}

%postun
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_uninstall_alternative " .. b .. "\n"))
end}

%check
# Don't run tests that require online connections
rm tests/dcerpc/test_bkrp.py
rm tests/dcerpc/test_dcomrt.py
rm tests/dcerpc/test_dhcpm.py
rm tests/dcerpc/test_drsuapi.py
rm tests/dcerpc/test_epm.py
rm tests/dcerpc/test_even.py
rm tests/dcerpc/test_even6.py
rm tests/dcerpc/test_fasp.py
rm tests/SMB_RPC/test_ldap.py
rm tests/dcerpc/test_lsad.py
rm tests/dcerpc/test_lsat.py
rm tests/dcerpc/test_mgmt.py
rm tests/dcerpc/test_mimilib.py
rm tests/SMB_RPC/test_nmb.py
rm tests/dcerpc/test_nrpc.py
rm tests/dcerpc/test_par.py
rm tests/SMB_RPC/test_rpch.py
rm tests/SMB_RPC/test_rpcrt.py
rm tests/dcerpc/test_rprn.py
rm tests/dcerpc/test_rrp.py
rm tests/dcerpc/test_samr.py
rm tests/dcerpc/test_scmr.py
rm tests/SMB_RPC/test_secretsdump.py
rm tests/SMB_RPC/test_smb.py
rm tests/dcerpc/test_srvs.py
rm tests/dcerpc/test_tsch.py
rm tests/dcerpc/test_wkst.py
rm tests/SMB_RPC/test_wmi.py
rm tests/misc/test_dcerpc_v5_ndr.py
rm tests/misc/test_structure.py
rm tests/SMB_RPC/test_smbserver.py
#%%pytest -k 'not (test_well_formed)'
%pytest

%files %{python_files}
%license LICENSE
%doc ChangeLog.md README.md
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_alternative %{_bindir}/" .. b .. "\n"))
end}
%{python_sitelib}/impacket
%{python_sitelib}/impacket-%{version}.dist-info

%changelog
* Wed Dec  4 2024 Martin Hauke <mardnh@gmx.de>
- Skip test tests/SMB_RPC/test_smbserver.py to fix the actual
  build failure.
* Tue Sep 17 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.12.0
  Library improvements
  * Fixed broken hRSetServiceObjectSecurity method.
  * Removed dsinternals dependency.
  * Fixed srvs.hNetrShareEnum returning erronous shares.
  * Fixed lmhash computing to support non standard characters in
    the password.
  * Assorted fixes when processing Unicode data.
  * Added [MS-GKDI] Group Key Distribution Protocol implementation.
  * Fixed incorrect padding in
    SMBSessionSetupAndX_Extended_ResponseData.
  * Upgraded dependency pyreadline -> pyreadline3.
  * SMB Server:
    + Added query information level 0x0109 for smb1
    "SMB_QUERY_FILE_STREAM_INFO".
    + Fixed filename encoding in queryPathInformation.
    + Fixed NextEntryOffset for large directory listings.
    + Fixed server returning an empty folder when cutting and
    pasting recursive directories.
  * DHCP: Fixed encoding issues.
  Example Improvements
  * multiple improvements, see
    https://github.com/fortra/impacket/releases/tag/impacket_0_12_0
  New Examples
  * describeTicket.py: Ticket describer and decrypter.
  * GetADComputers.py: Query's DC via LDAP and returns the COMPUTER
    objects and the useful attributes such as full dns name,
    operating system name and version.
  * GetLAPSPassword.py: Extract LAPS passwords from LDAP.
  * dacledit.py: This script can be used to read, write, remove,
    backup, restore ACEs (Access Control Entries) in an object
    DACL (Discretionary Access Control List).
  * owneredit.py: Added this script to abuse WriteOwner
    (ADS_RIGHT_WRITE_OWNER) access rights. This allows to take
    ownership of another object, and then edit that object's DACL.
- Remove patch:
  * remove-future-requirement.patch (was merged upstream)
* Thu Nov 23 2023 Martin Hauke <mardnh@gmx.de>
- Add python-dsinternals to BuildRequires
* Tue Sep  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-future-requirement.patch, remove future requirement.
- Switch to pyproject macros.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.11.0
  Library improvements
  * Added new Kerberos error codes.
  * Added [MS-TSTS] Terminal Services Terminal Server Runtime
    Interface Protocol implementation.
  * Changed the setting up for new SSL connections.
  * Added a callback function to smbserver for incoming
    authentications.
  * Fix crash in winregistry.
  * Fixes in IDispatch derived classes in comev implementation.
  * Fix CVE-2020-17049 in ccache.py.
  * Smbserver: Added SMB2_FILE_ALLOCATION_INFO type determination.
  * tds: Fixed python3 incompatibility when receiving over TLS
    socket.
  * crypto: Ensure passwords are utf-8 encoded before deriving
    Kerberos keys.
  * ese: Fixed python3 incompatibility when reading from db.
  * ldap queries: Escaped characters are now correctly parsed.
  * Support SASL authentication in ldap protocol.
  Examples improvements
  * GetADUsers.py, GetNPUsers.py, GetUserSPNs.py and
    findDelegation.py:
    + Added dc-host option to connect to specific KDC using its
    FQDN or NetBIOS name.
  * GetNPUsers.py
    + Printing TGT in stdout despite -outputfile parameter.
    + Fixed output hash format for AES128/256 (etype 17/18).
  * GetUserSPNs.py:
    + Added LDAP paged search
    + Added a -stealth flag to remove the SPN filter from the LDAP
    query.
    + Improved searchFilter
    + Use LDAP paged search
  * psexec.py:
    + Added support for name customization using a custom binary
    file.
  * smbexec.py:
    + Security fixes for privilege escalation vulnerabilities.
    + Fixed python3 compatibility issues, added workaround TCP
    over NetBIOS being disabled.
  * secretsdump.py:
    + Added a new option to extract only NTDS.DIT data for specific
    users based on an LDAP filter.
    + Security fixes for privilege escalation vulnerabilities.
  * mssqlclient.py:
    + Added multiple new commands. Now supports xp_dirtree execution
  * ntlmrelayx.py:
    + Added ability to trigger SQLShell when running ntlmrelayx in
    interactive mode.
    + Added filter option to the socks command in ntlmrelayx CLI.
    + Added ability to register DNS records through LDAP.
  * addcomputer.py, rbcd.py:
    + Allow weak TLS ciphers for LDAP connections.
  * Get-GPPPassword.py:
    + Better handling of various XML files in Group Policy
    Preferences.
  * smbclient.py:
    + Added recursive file listing.
  * ticketer.py:
    + Ticket duration is now specified in hours instead of days.
    + Added extra-pac implementation.
  New examples
  * net.py
    + Implementation of windows net.exe builtin tool.
  * changepasswd.py
    + New example that allows password changing or reseting through
    multiple protocols.
  * DumpNTLMInfo.py
    + New example that dumps remote host information in ntlm
    authentication model, without credentials.
    For SMB protocols v1, v2 and v3.
- Optimize spec file
  * define a list of all the binaries and loop over this list when
    needed.
* Fri Jun  2 2023 pgajdos@suse.com
- update to version 0.10.0
  * Dropped support for Python 2.7.
  * Refactored the testing infrastructure (@martingalloar):
  * Added `pytest` as the testing framework to organize and mark test
    cases. `Tox` remain as the automation framework, and `Coverage.py`
    for measuring code coverage.
  * Custom bash scripts were replaced with test cases auto-discovery.
  * Local and remote test cases were marked for easy run and configuration.
  * DCE/RPC endpoint test cases were refactored and moved to a new layout.
  * An initial testing guide with the main steps to prepare a testing environment and run them.
  * Fixed a good amount of DCE/RPC endpoint test cases that were failing.
  * Added tests for `[MS-PAR]`, `[MS-RPRN]`, CCache and DPAPI.
  * Added a function to compute the Netlogon Authenticator at client-side in `[MS-NRPC]` (@0xdeaddood)
  * Added `[MS-DSSP]` protocol implementation (@simondotsh)
  * Added GetDriverDirectory functions to `[MS-PAR]` and `[MS-RPRN]` (@raithedavion)
  * Refactored the Credential Cache:
  * Added new parseFile function to ccache.py (@rmaksimov)
  * Added support for loading CCache Version 3 (@reznok)
  * Modified fromKRBCRED function used to load a Kirbi file (@0xdeaddood)
  * Fixed Ccache to Kirbi conversion (@ShutdownRepo)
  * Fixed default NTLM server challenge in smbserver (@rtpt-jonaslieb)
  * Fixed WMI objects parsing (@franferrax)
  * Added the RpcAddPrinterDriverEx method and related structures to `[MS-RPRN]`: Print System Remote Protocol (@cube0x0)
  * Initial implementation of `[MS-PAR]`: Print System Asynchronous Remote Protocol (@cube0x0)
  * Complying `[MS-RPCH]` with HTTP/1.1 (@mohemiv)
  * Added return of server time in case of Kerberos error (@ShutdownRepo and @Hackndo)
* Wed Jun  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.23
  Library improvements
  * Support connect timeout with SMBTransport.
  * Speeding up DcSync.
  * Fixed Python3 issue when serving SOCKS5 requests.
  * Fixed Path Traversal vulnerabilities in smbserver.py .
    CVE-2021-31800
  * Fixed POST request processing in httprelayserver.py .
  * Added cat command to smbclient.py .
  * Added new features to the LDAP Interactive Shell to facilitate
    AD exploitation.
  * Python 3.9 support
- Drop not longer needed patch:
  * 1054.patch
* Sat Apr 24 2021 Martin Hauke <mardnh@gmx.de>
- Python 3.9 is not supported yet - skip builds for now
* Mon Mar  1 2021 Martin Hauke <mardnh@gmx.de>
- Fix TW build
* Mon Nov 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.22
  Library improvements
  * Added implementation of RPC over HTTP v2 protocol.
  * Added MS-NSPI, MS-OXNSPI and MS-OXABREF protocol
    implementations.
  * Improved the multi-page results in LDAP queries.
  * NDR parser optimization.
  * Improved serialization of WMI method parameters.
  * Introduce the MS-NLMP 2.2.2.10 VERSION structure in
    NTLMAuthNegotiate messages.
  * Added some NETLOGON structs for NetrServerPasswordSet2.
  * Python 3.8 support.
  Examples improvements
  * atexec.py: Fixed after MS patches related to RPC attacks.
  * dpapi.py: Added -no-pass, pass-the-hash and AES Key support
    for backup subcommand.
  * GetNPUsers.py: Added ability to enumerate targets with
    Kerberos KRB5CC.
  * GetUserSPNs.py: Added new features for kerberoasting.
  * ntlmrelayx.py:
    + Added ability to relay on new Windows versions that have
    SMB guest access disabled by default.
    + Added option to specify the NTLM Server Challenge used
    when receiving a connection.
    + Added relaying to RPC support.
    + Implemented WCFRelayServer.
    + Added Zerologon DCSync Relay Client.
    + Fixed issue in ldapattack.py when relaying and creating
    computer in CN=Computers.
    + rpcdump.py: Added RPC over HTTP v2 support.
    + secretsdump.py:
  - Added ability to specifically delete a shadow based on
    its ID.
  - Dump plaintext machine account password when dumping the
    local registry secrets.
  New examples
  * exchanger.py: A tool for connecting to MS Exchange via RPC
    over HTTP v2.
  * rpcmap.py: Scan for listening DCE/RPC interfaces.
* Wed Jul  8 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.9.21
